from django.conf import settings
from django.contrib import admin
from .models import EmailTemplate, Logs, SysProcess


class LogsAdmin(admin.ModelAdmin):
    list_display = ('log_name', '_log_level', '_log_msg', 'created_at')
    fields = ('log_name', 'log_level', 'log_msg')
    list_filter = ['created_at', 'log_level']
    search_fields = ['log_name', 'log_level', 'log_msg']

    def __init__(self, *args, **kwargs):
        super(LogsAdmin, self).__init__(*args, **kwargs)
        self.list_display_links = None

    def has_add_permission(self, request):
        return False


class EmailTemplateAdmin(admin.ModelAdmin):
    list_display = ('name', 'subject', '_message')


class SysProcessAdmin(admin.ModelAdmin):
    list_display = ('content_id', 'content_type', 'priority', 'status', 'created_at')
    fields = ('content_id', 'content_type', 'priority', 'status',)
    list_filter = ['priority', 'content_id', 'content_type']
    search_fields = ['content_id', 'content_type', 'priority', 'status', ]

    def __init__(self, *args, **kwargs):
        super(SysProcessAdmin, self).__init__(*args, **kwargs)
        self.list_display_links = None

    def has_add_permission(self, request):
        return False


admin.site.site_header = settings.CNM_CONFIGS['site_name']
admin.site.register(EmailTemplate, EmailTemplateAdmin)
admin.site.register(Logs, LogsAdmin)
admin.site.register(SysProcess, SysProcessAdmin)



from .services.email import EmailService


def sendmail(request):
    try:
        data = EmailService('Andrew', 'mrhieutrieu@gmail.com', 'Hieu Trieu', 'hieu@cinnamon.is') \
            .get_content_by_name('template_1') \
            .render_content(name="My Name",
                            candidate_name="Candidate Name",
                            candidate_phone="Candidate Phone",
                            candidate_email="Candidate Email",
                            admin_name="Admin Name",
                            admin_email="admin@gmail.com",
                            ) \
            .send()
    except Exception as Ex:
        print(Ex)



import emails
import re
from django.conf import settings
from ..models import EmailTemplate


class EmailService:
    mail_obj = {}
    html_content = ''
    template_layout = 'templates/email_templates/'
    template_file = template_layout + 'email_layout.html'
    email_config = {}
    name_from = ''
    email_from = ''
    name_to = ''
    email_to = ''

    def __init__(self, name_from, email_from, name_to, email_to):
        self.email_config = settings.EMAIL_CONFIGS
        self.name_from = name_from
        self.email_from = email_from
        self.name_to = name_to
        self.email_to = email_to

    def send(self):
        message = emails.html(
            html=self.html_content,
            subject=self.mail_obj['subject'],
            mail_from=(self.name_from, self.email_from)
        )
        sendmail = message.send(
            to=(self.name_to, self.email_to),
            smtp=self.email_config
        )
        return sendmail.status_code

    def render_content(self, **kwargs):
        for karg in kwargs:
            self.html_content = self.template_replace(karg, kwargs[karg])
        with open(self.template_file) as temp:
            self.html_content = temp.read().replace('{{ message }}', self.html_content)
        return self

    def get_content_by_name(self, email_name, layout_name=None):
        self.mail_obj = EmailTemplate.objects.values('layout_name', 'subject', 'message').get(name=email_name)
        if layout_name != None:
            self.template_file = self.template_layout + '{}.html'.format(layout_name)
        else:
            self.template_file = self.template_layout + '{}.html'.format(self.mail_obj['layout_name'])
        return self

    def template_replace(self, old, new):
        matchs = re.findall('{{(.*?)}}', self.mail_obj['message'], re.DOTALL)
        for s in matchs:
            if s.strip() == old:
                self.mail_obj['message'] = self.mail_obj['message'].replace('{{' + s + '}}', new)
        return self.mail_obj['message']



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-07-20 04:01
from __future__ import unicode_literals

import ckeditor.fields
import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='EmailTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('layout_name', models.CharField(choices=[('email_layout', 'email_layout'), ('email_layout_1', 'email_layout_1'), ('email_layout_2', 'email_layout_2')], default='email_layout', max_length=255)),
                ('name', models.CharField(max_length=255, unique=True)),
                ('subject', models.CharField(max_length=255)),
                ('message', ckeditor.fields.RichTextField()),
            ],
            options={
                'db_table': 'email_templates',
            },
        ),
        migrations.CreateModel(
            name='Logs',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('log_name', models.CharField(max_length=255)),
                ('log_level', models.CharField(choices=[('log', 'Log'), ('info', 'Info'), ('exception', 'Exception'), ('error', 'Error')], default='log', max_length=50)),
                ('log_msg', models.TextField()),
                ('created_at', models.DateTimeField(blank=True, default=datetime.datetime.now)),
            ],
            options={
                'db_table': 'logs',
            },
        ),
        migrations.CreateModel(
            name='SysProcess',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('content_id', models.IntegerField()),
                ('content_type', models.CharField(max_length=50)),
                ('priority', models.IntegerField()),
                ('status', models.IntegerField(default=0)),
                ('created_at', models.DateTimeField(blank=True, default=datetime.datetime.now)),
            ],
            options={
                'db_table': 'sys_process',
            },
        ),
    ]



# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.txt'), encoding='utf-8') as f:
    long_description = f.read()


setup(
    name="cnm systems",
    version="1.0.4",
    author="Andrew Carnegie",
    author_email="mrhieutrieu@gmail.com",
    description=("System of Cinnamon"),
    license="BSD",
    keywords="development",
    url="https://github.com/hieutrieu/systems",
	packages=['cnm_systems', 'cnm_systems/services','cnm_systems/migrations'],
    long_description=long_description,
	install_requires=['emails', 'django-ckeditor'],
    classifiers=[
		"License :: OSI Approved :: MIT License",
        "Framework :: Django",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
    ],	
)


import os
import glob
from django.conf import settings
from datetime import datetime
from django.db import models
from django.utils.translation import gettext_lazy as _
from tinymce.models import HTMLField
from ckeditor.fields import RichTextField


class Logs(models.Model):
    TYPE_CHOICES = (
        ('log', 'Log'),
        ('info', 'Info'),
        ('exception', 'Exception'),
        ('error', 'Error'),
    )
    log_name = models.CharField(max_length=255)
    log_level = models.CharField(max_length=50, null=False, default='log', choices=TYPE_CHOICES)
    log_msg = models.TextField()
    created_at = models.DateTimeField(default=datetime.now, blank=True)

    def __str__(self):
        return self.log_name

    def _log_msg(self):
        return self.log_msg

    def _log_level(self):
        return self.log_level

    _log_msg.allow_tags = True  # set this to not HTML-escape the output
    _log_msg.short_description = 'Message'
    _log_level.short_description = 'Level'

    class Meta:
        db_table = "logs"
        verbose_name = _('log')
        verbose_name_plural = _('logs')


class EmailTemplate(models.Model):
    path = settings.TEMPLATES[0]['DIRS'][0]
    folder = path + '\\email_templates\\*'
    template_files = [os.path.basename(x) for x in glob.glob(folder)]
    LAYOUT_CHOICES = [
        ('email_layout', 'email_layout'),
    ]
    for file in template_files:
        name = os.path.splitext(file)[0]
        LAYOUT_CHOICES.append((name, name,))

    layout_name = models.CharField(max_length=255, null=False, default='email_layout', choices=LAYOUT_CHOICES)
    name = models.CharField(max_length=255, unique=True)
    subject = models.CharField(max_length=255)
    if settings.CNM_CONFIGS['editor'].lower() == 'ckeditor':
        message = RichTextField(config_name="default")
    else:
        message = models.TextField()

    def _message(self):
        return self.message

    _message.allow_tags = True  # set this to not HTML-escape the output
    _message.short_description = 'Message'

    def __str__(self):
        return self.subject

    class Meta:
        db_table = "email_templates"



class SysProcess(models.Model):
    content_id = models.IntegerField()
    content_type = models.CharField(max_length=50)
    priority = models.IntegerField()
    status = models.IntegerField(default=0)
    created_at = models.DateTimeField(default=datetime.now, blank=True)

    class Meta:
        db_table = "sys_process"
        verbose_name = _('process')
        verbose_name_plural = _('processes')
